@@ -1,5 +1,5 @@
 #
-# Copyright 2008-2012 Universidad Complutense de Madrid
+# Copyright 2008-2013 Universidad Complutense de Madrid
 # 
 # This file is part of Numina
 # 
@@ -19,7 +19,7 @@
 
 '''Different methods for combining lists of arrays.'''
 
-import numpy # pylint: disable-msgs=E1101
+import numpy
 
 from numina.array._combine import generic_combine as internal_generic_combine
 from numina.array._combine import sigmaclip_method, quantileclip_method, minmax_method
