@@ -1,5 +1,5 @@
 #
-# Copyright 2008-2012 Universidad Complutense de Madrid
+# Copyright 2008-2013 Universidad Complutense de Madrid
 # 
 # This file is part of Numina
 # 
@@ -20,10 +20,10 @@
 from .recipes import BaseRecipe
 from .recipes import list_recipes
 from .dataframe import DataFrame
-from .pipeline import init_pipeline_system, BaseInstrument, BasePipeline
-from .pipeline import InstrumentConfiguration
-from .pipeline import get_recipe, get_instruments
+from .pipeline import Instrument, Pipeline, InstrumentConfiguration
+from .pipeline import ObservingMode
 from .pipeline import import_object
+from .pipeline import drp_load, init_drp_system
 from .requirements import RequirementParser, DataProductRequirement
 from .requirements import Parameter, Requirement
 from .products import DataProduct, FrameDataProduct
